==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/nl.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Uw instellingen zijn bijgewerkt",
"Activity" => "Activiteit",
"A file or folder has been <strong>shared</strong>" => "Een bestand of map is <strong>gedeeld</strong>",
"A new file or folder has been <strong>created</strong> in a shared folder" => "Een nieuw bestand of map is <strong>aangemaakt</strong> in een gedeelde map",
"A file or folder has been <strong>changed</strong> in a shared folder" => "Een bestand of map is <strong>gewijzigd</strong> in een gedeelde map",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "Een bestand of map is <strong>verwijderd</strong> uit een gedeelde map",
"You created %1\$s" => "U creëerde %1\$s",
"%2\$s created %1\$s" => "%2\$s creëerde %1\$s",
"You changed %1\$s" => "U wijzigde %1\$s",
"%2\$s changed %1\$s" => "%2\$s wijzigde %1\$s",
"You deleted %1\$s" => "U verwijderde %1\$s",
"%2\$s deleted %1\$s" => "%2\$s verwijderde %1\$s",
"You shared %1\$s with %2\$s" => "U deelde %1\$s met %2\$s",
"You shared %1\$s with group %2\$s" => "U deelde %1\$s met groep %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s deelde %1\$s met u",
"You shared %1\$s via link" => "U deelde %1\$s via link",
"Activity notification" => "Activiteitenmelding",
"All Activities" => "Alle activiteiten",
"Activities by you" => "Activiteiten van uzelf",
"Activities by others" => "Activiteiten van anderen",
"Shares" => "Shares",
"Files" => "Bestanden",
"%s and %s" => "%s en %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s en <strong class=\"tooltip\" title=\"%s\">%n meer</strong>","%s en <strong class=\"tooltip\" title=\"%s\">%n meer</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s en %n meer","%s en %n meer"),
"Hello %s," => "Hallo %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "U ontvangt dit bericht omdat het afgelopen uur het volgende gebeurde op %s",
"You are receiving this email because in the last day the following things happened at %s" => "U ontvangt dit bericht omdat de afgelopen dag het volgende gebeurde op %s",
"You are receiving this email because in the last week the following things happened at %s" => "U ontvangt dit bericht omdat de afgelopen week het volgende gebeurde op %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "U ziet hier een lijst met activiteiten als u gebruik gaat maken van uw %s.",
"No more events to load" => "Geen activiteiten meer om te laden ",
"Enable RSS feed" => "Aanzetten RSS kanaal",
"Notifications" => "Meldingen",
"Mail" => "E-mail",
"Stream" => "Stroom",
"You need to set up your email address before you can receive notification emails." => "U moet uw e-mailadres instellen voordat u meldingen kunt ontvangen.",
"Send emails:" => "Verstuur e-mails:",
"Hourly" => "Per uur",
"Daily" => "Dagelijks",
"Weekly" => "Wekelijks",
"Activity feed" => "Activiteitenkanaal",
"Personal activity feed for %s" => "Persoonlijk activiteitenkanaal voor %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/nl.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Uw instellingen zijn bijgewerkt",
"Activity" => "Activiteit",
"A file or folder has been <strong>shared</strong>" => "Een bestand of map is <strong>gedeeld</strong>",
"A new file or folder has been <strong>created</strong>" => "Een nieuw bestand of map is <strong>aangemaakt</strong>",
"A file or folder has been <strong>changed</strong>" => "Een bestand of map is <strong>gewijzigd</strong>",
"A file or folder has been <strong>deleted</strong>" => "Een bestand of map is <strong>verwijderd</strong>",
"You created %1\$s" => "U creëerde %1\$s",
"%2\$s created %1\$s" => "%2\$s creëerde %1\$s",
"You changed %1\$s" => "U wijzigde %1\$s",
"%2\$s changed %1\$s" => "%2\$s wijzigde %1\$s",
"You deleted %1\$s" => "U verwijderde %1\$s",
"%2\$s deleted %1\$s" => "%2\$s verwijderde %1\$s",
"You shared %1\$s with %2\$s" => "U deelde %1\$s met %2\$s",
"You shared %1\$s with group %2\$s" => "U deelde %1\$s met groep %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s deelde %1\$s met u",
"You shared %1\$s via link" => "U deelde %1\$s via link",
"Activity notification" => "Activiteitenmelding",
"All Activities" => "Alle activiteiten",
"Activities by you" => "Activiteiten van uzelf",
"Activities by others" => "Activiteiten van anderen",
"Shares" => "Shares",
"Files" => "Bestanden",
"%s and %s" => "%s en %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s en <strong class=\"tooltip\" title=\"%s\">%n meer</strong>","%s en <strong class=\"tooltip\" title=\"%s\">%n meer</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s en %n meer","%s en %n meer"),
"Hello %s," => "Hallo %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "U ontvangt dit bericht omdat het afgelopen uur het volgende gebeurde op %s",
"You are receiving this email because in the last day the following things happened at %s" => "U ontvangt dit bericht omdat de afgelopen dag het volgende gebeurde op %s",
"You are receiving this email because in the last week the following things happened at %s" => "U ontvangt dit bericht omdat de afgelopen week het volgende gebeurde op %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "U ziet hier een lijst met activiteiten als u gebruik gaat maken van uw %s.",
"No more events to load" => "Geen activiteiten meer om te laden ",
"Enable RSS feed" => "Aanzetten RSS kanaal",
"Notifications" => "Meldingen",
"Mail" => "E-mail",
"Stream" => "Stroom",
"Notify about my own actions" => "Melding over mijn eigen acties",
"You need to set up your email address before you can receive notification emails." => "U moet uw e-mailadres instellen voordat u meldingen kunt ontvangen.",
"Send emails:" => "Verstuur e-mails:",
"Hourly" => "Per uur",
"Daily" => "Dagelijks",
"Weekly" => "Wekelijks",
"Activity feed" => "Activiteitenkanaal",
"Personal activity feed for %s" => "Persoonlijk activiteitenkanaal voor %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
